==> mapguide-1.0.1.tar.gz: mapguide-1.0.1/Server/src/Gws/GwsResource/GwsResource.h <==
//
//  Copyright (C) 2004-2006  Autodesk, Inc.
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of version 2.1 of the GNU Lesser
//  General Public License as published by the Free Software Foundation.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by GWSResource.rc
//
#define IDS_STRING_CACHEID              1008
#define IDS_STRING_UPDATEFAILED         1009
#define IDS_STRING_eGwsOutOfMemory      1010
#define IDS_STRING_eGwsFailedToCommitTransaction 1011
#define IDS_STRING_eGwsFailedToCommitSomeTransactions 1012
#define IDS_STRING_eGwsFailedToCommitCache 1013
#define IDS_STRING_eGwsFailedToRollbackTransaction 1014
#define IDS_STRING_eGwsFailedToRollbackSomeTransactions 1015
#define IDS_STRING_eGwsFailedToRollbackCache 1016
#define IDS_STRING_eGwsNullPointer      1017
#define IDS_STRING_eGwsFailedToCreateThread 1018
#define IDS_STRING_eGwsFailedToPrepareQuery 1019
#define IDS_STRING_eGwsFailedToExecuteQuery 1020
#define IDS_STRING_eGwsGetCachedFeaturesByIdsFailed 1021
#define IDS_STRING_eGwsIsReadOnly       1022
#define IDS_STRING_eGwsFileNotFound     1023
#define IDS_STRING_eGwsCannotCopyGwsCacheFiles 1024
#define IDS_STRING_eGwsFailedToDropLayerStorage 1025
#define IDS_STRING_eGwsOutstandingSessions 1026
#define IDS_STRING_eGwsClosedFeatureIterator 1027
#define IDS_STRING_eGwsDisconnected     1028
#define IDS_STRING_eGwsInvalidGwsName   1029
#define IDS_STRING_eGwsFailedToReadGws  1030
#define IDS_STRING_eGwsAlreadyOpened    1031
#define IDS_STRING_eGwsGwsAlreadyExists 1032
#define IDS_STRING_eGwsClosed           1033
#define IDS_STRING_eGwsFailedToWriteGws 1034
#define IDS_STRING_eGwsFailed           1035
#define IDS_STRING_eGwsInvalidCacheId   1036
#define IDS_STRING_eGwsNoEditSetInDirectUpdateMode 1037
#define IDS_STRING_eGwsFailedToInitializeFdoConnection 1037
#define IDS_STRING_eGwsConnectionParameterNotFound 1038
#define IDS_STRING_eFailedToStartFeatureSourceSession 1039
#define IDS_STRING_eGwsFailedToCacheFeatures 1040
#define IDS_STRING_eGwsLayerSourceNotPartOfGws 1041
#define IDS_STRING_eGwsFeatureSourceDoesnotSupportLongIdentity 1042
#define IDS_STRING_eGwsFailedToDeleteFeature 1043
#define IDS_STRING_eGwsFailedToInsertFeature 1044
#define IDS_STRING_eGwsInvalidParameter 1045
#define IDS_STRING_eGwsIndexOutOfBounds 1046
#define IDS_STRING_eGwsFailedToGetLockInformation 1047
#define IDS_STRING_eGwsObjectsRemainInEditSet 1048
#define IDS_STRING_eGwsOk               1049
#define IDS_STRING_eGwsWarningFailedToLockSomeFeatures 1050
#define IDS_STRING_eGwsWarningFailedToUnlockSomeFeatures 1051
#define IDS_STRING_eGwsWarningFailedToConnectSomeFeatureSources 1052
#define IDS_STRING_eGwsWarningFeatureSourceSessionNotStarted 1053
#define IDS_STRING_eGwsNotSupported     1054
#define IDS_STRING_eGwsFdoProviderError 1055
#define IDS_STRING_eGwsConnected        1056
#define IDS_STRING_eGwsConnectionNotInitialized 1057
#define IDS_STRING_eFailedToStartTransaction 1058
#define IDS_STRING_eGwsNoTransactionStarted 1059
#define IDS_STRING_eGwsFailedToTerminateSession 1060
#define IDS_STRING_eGwsSessionNotFound  1061
#define IDS_STRING_eGwsFailedToFlushChanges 1062
#define IDS_STRING_eGwsFailedToDesribeClass 1063
#define IDS_STRING_eGwsFeatureStorageDoesNotExist 1064
#define IDS_STRING_eGwsFeatureStorageAlreadyCreated 1065
#define IDS_STRING_eGwsFailedToCreateQuery 1066
#define IDS_STRING_eGwsDoesNotSupportRightJoin 1067
#define IDS_STRING_eGwsDoesNotSupportLeftJoin 1068
#define IDS_STRING_eGwsWarningStorageAlreadyLoaded 1069
#define IDS_STRING_eGwsNoExplicitFeatureSourceInLayerQuery 1070
#define IDS_STRING_eGwsDataSourceNotFound 1071
#define IDS_STRING_eGwsDataSourceAlreadyExists 1072
#define IDS_STRING_eGwsDataSourceAlreadyAdded 1073
#define IDS_STRING_eGwsFailedToOpenFdoConnection 1074
#define IDS_STRING_eGwsFailedToCloseFdoConnection 1075
#define IDS_STRING_eGwsFailedToCreateLayerStorage 1076
#define IDS_STRING_eGwsFailedToAddPropertyDefinition 1077
#define IDS_STRING_eGwsFailedToAddIdentityPropertyDefinition 1078
#define IDS_STRING_eGwsFailedToCreateGwsFeatureDefintion 1079
#define IDS_STRING_eGwsStorageNotLoaded 1080
#define IDS_STRING_eGwsFdoReadOnlyProperty 1081
#define IDS_STRING_eGwsFdoQueryIsNotPrepared 1082
#define IDS_STRING_eGwsFdoCommandIsNotPrepared 1083
#define IDS_STRING_eGwsFdoLockConflict  1084
#define IDS_STRING_eGwsFdoVersionConflict 1085
#define IDS_STRING_eGwsFailedToExecuteCommand 1086
#define IDS_STRING_eGwsFailedToPrepareCommand 1087
#define IDS_STRING_eGwsFailedToFetchResults 1088
#define IDS_STRING_eGwsFailedToGetProperty 1089
#define IDS_STRING_eGwsFdoInvalidPropertyType 1090
#define IDS_STRING_eGwsFdoUnsupportedPropertyType 1091
#define IDS_STRING_eFailedToStartLayerSourceSession 1092
#define IDS_STRING_eGwsFeatureDoesNotExist 1093
#define IDS_STRING_eGwsFeatureHasBeenDeleted 1094
#define IDS_STRING_eGwsRevisionNumbersConflict 1095
#define IDS_STRING_eGwsInvalidPropertyName 1096
#define IDS_STRING_eGwsFailedToLockFeatures 1097
#define IDS_STRING_eGwsFailedToUnlockFeatures 1098
#define IDS_STRING_eGwsCannotRemoveNewFeatureFromEditSet 1099
#define IDS_STRING_eGwsJoinPropertiesCardinalityViolation 1100
#define IDS_STRING_eGwsGwsCacheCorrupted 1101
#define IDS_STRING_eGwsFailedToUpdateFeature 1102
#define IDS_STRING_eGwsEditSetUnavailable 1103
#define IDS_STRING_eGwsFailedToSaveGws  1104
#define IDS_STRING_eGwsFailedToDescribeLayer 1105
#define IDS_STRING_eGwsWarningNotCaching 1106
#define IDS_STRING_eGwsWarningStillLoadingCache 1107
#define IDS_STRING_eGwsWarningCacheLoadingStopped 1108
#define IDS_STRING_eGwsItemAlreadyAdded 1109
#define IDS_STRING_eGwsItemNotFound     1110
#define IDS_STRING_eGwsFailedToCommitLayerSourceTransaction 1111
#define IDS_STRING_eGwsCannotGetPropertyValueOffline 1112
#define IDS_STRING_eGwsFeatureNotFoundOnline 1113
#define IDS_STRING_eFailedToCreateMutableFeature 1114
#define IDS_STRING_eGwsFailedToCreateMutableFeature 1114
#define IDS_STRING_eGwsWarinigSomePropertyValuesAreUninitialized 1115
#define IDS_STRING_eGwsWarningSomePropertyValuesAreUninitialized 1115
#define IDS_STRING_eGwsNotAFeatureClass 1116
#define IDS_STRING_eGwsNoGeometryProperty 1117
#define IDS_STRING_eGwsVersionNotFound  1118
#define IDS_STRING_eGwsVersionResolutionFailed 1119
#define IDS_STRING_eGwsFailedToPrepareLayerSourceQuery 1120
#define IDS_STRING_eGwsDeleteCommandNotSupported 1121
#define IDS_STRING_eGwsUpdateCommandNotSupported 1122
#define IDS_STRING_eGwsInsertCommandNotSupported 1123
#define IDS_STRING_eGwsWrongLayerFeatureId 1124
#define IDS_STRING_eGwsFailedToSaveEditSet 1125
#define IDS_STRING_eGwsMissingLeftJoinAttributes 1126
#define IDS_STRING_eGwsInvalidJoinAttributeType 1127
#define IDS_STRING_eGwsJoinAttributesAreNotComparable 1128
#define IDS_STRING_eGwsFailedToDeleteLayerFeature 1129
#define IDS_STRING_eGwsFailedToInsertLayerFeature 1130
#define IDS_STRING_eGwsFailedToUpdateLayerFeature 1131
#define IDS_STRING_eGwsClassNotReferencedByLayer 1132
#define IDS_STRING_eGwsInvalidFeatureSourceName 1133
#define IDS_STRING_eGwsOperationInProgress 1134
#define IDS_STRING_eGwsOperationIsNotRunning 1135
#define IDS_STRING_eGwsOperationCanceled 1136
#define IDS_PROGRESS_READINGMETADATA    1137
#define IDS_PROGRESS_POPULATINGCACHE    1138
#define IDS_PROGRESS_COMMITTING         1139
#define IDS_PROGRESS_COLLECTINGFEATURESTATUS 1140
#define IDS_PROGRESS_UPDATINGFEATURESTATUS 1141
#define IDS_PROGRESS_VERIFYINGREVISIONNUMBERS 1142
#define IDS_PROGRESS_ACQUIRINGLOCKS     1143
#define IDS_PROGRESS_RELEASINGLOCKS     1144
#define IDS_PROGRESS_WRITINGFEATURES    1145
#define IDS_PROGRESS_OPERATIONSTARTED   1146
#define IDS_PROGRESS_COLLECTINGREVISIONNUMBERS 1147
#define IDS_PROGRESS_OPERATIONCANCELED  1148
#define IDS_PROGRESS_OPERATIONFAILED    1149
#define IDS_PROGRESS_OPERATIONWITHWARNING 1150
#define IDS_PROGRESS_OPERATIONSUCESSFUL 1151
#define IDS_STRING_eGwsFailedToTransformFeature 1152
#define IDS_STRING_eGwsFailedToParseFeature 1153
#define IDS_STRING_eGwsSCNotFound       1154
#define IDS_STRING_eGwsFailedToHandleSourceCS 1155
#define IDS_STRING_eGwsFailedToHandleDestinationCS 1156
#define IDS_STRING_eGwsFailedToInitializeCSC 1157
#define IDS_STRING_eGwsFeatureSourceSessionTerminated 1158
#define IDS_STRING_eGwsLayerSourceSessionTerminated 1159
#define IDS_STRING_eGwsWarningFeatureSourceClassIsNotVersionEnabled 1160
#define IDS_STRING_eGwsCannotSetActiveVersion 1161
#define IDS_STRING_eGwsNotAllFeatureSourcesConnected 1162
#define IDS_STRING_eGwsFailedToUpdateLayerSourceVersion 1163
#define IDS_STRING_eGwsCannotMakeUniqueGwsName 1164
#define IDS_PROGRESS_READINGFEATUREIDS  1165
#define IDS_STRING_eGwsWarningExtentsNotYetAvailable 1166
#define IDS_PROGRESS_PROCESSING_LAYER   1167
#define IDS_PROGRESS_PROCESSINGLAYER    1167
#define IDS_STRING1168                  1168
#define IDS_STRING_eGwsProviderNotRegistered 1168
#define IDS_STRING_eGwsSucceeded 1169
#define IDS_STRING_eGwsRevisionNumberConflict 1170
#define IDS_STRING_eGwsLockRejected 1171
#define IDS_STRING_eGwsUnlockRejected 1172
#define IDS_STRING_eGwsLockedOffline 1173
#define IDS_STRING_eGwsCannotUnlockOffline 1174
#define IDS_STRING_eGwsFeatureAlreadyInEditSet 1175
#define IDS_STRING_eGwsSkippedNewFeature 1176
#define IDS_STRING_eGwsSkippedNotLockedFeature 1177
#define IDS_STRING_eGwsFeatureNotSaved 1178
#define IDS_STRING_eGwsNotProcessed 1179
#define IDS_STRING_eGwsCannotRemoveModifedFeatureOffline 1180
#define IDS_STRING_eGwsNewFeatureCannotBeRemoved 1181
#define IDS_STRING_eGwsNewFeatureRemoved 1182


// Next default values for new objects
//
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        1131
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1000
#define _APS_NEXT_SYMED_VALUE           1000
#endif
#endif

==> mapguide-1.2.0.tar.gz: mapguide-1.2.0/Server/src/Gws/GwsResource/GwsResource.h <==
//
//  Copyright (C) 2004-2007 by Autodesk, Inc.
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of version 2.1 of the GNU Lesser
//  General Public License as published by the Free Software Foundation.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by GWSResource.rc
//
#define IDS_STRING_CACHEID              1008
#define IDS_STRING_UPDATEFAILED         1009
#define IDS_STRING_eGwsOutOfMemory      1010
#define IDS_STRING_eGwsFailedToCommitTransaction 1011
#define IDS_STRING_eGwsFailedToCommitSomeTransactions 1012
#define IDS_STRING_eGwsFailedToCommitCache 1013
#define IDS_STRING_eGwsFailedToRollbackTransaction 1014
#define IDS_STRING_eGwsFailedToRollbackSomeTransactions 1015
#define IDS_STRING_eGwsFailedToRollbackCache 1016
#define IDS_STRING_eGwsNullPointer      1017
#define IDS_STRING_eGwsFailedToCreateThread 1018
#define IDS_STRING_eGwsFailedToPrepareQuery 1019
#define IDS_STRING_eGwsFailedToExecuteQuery 1020
#define IDS_STRING_eGwsGetCachedFeaturesByIdsFailed 1021
#define IDS_STRING_eGwsIsReadOnly       1022
#define IDS_STRING_eGwsFileNotFound     1023
#define IDS_STRING_eGwsCannotCopyGwsCacheFiles 1024
#define IDS_STRING_eGwsFailedToDropLayerStorage 1025
#define IDS_STRING_eGwsOutstandingSessions 1026
#define IDS_STRING_eGwsClosedFeatureIterator 1027
#define IDS_STRING_eGwsDisconnected     1028
#define IDS_STRING_eGwsInvalidGwsName   1029
#define IDS_STRING_eGwsFailedToReadGws  1030
#define IDS_STRING_eGwsAlreadyOpened    1031
#define IDS_STRING_eGwsGwsAlreadyExists 1032
#define IDS_STRING_eGwsClosed           1033
#define IDS_STRING_eGwsFailedToWriteGws 1034
#define IDS_STRING_eGwsFailed           1035
#define IDS_STRING_eGwsInvalidCacheId   1036
#define IDS_STRING_eGwsNoEditSetInDirectUpdateMode 1037
#define IDS_STRING_eGwsFailedToInitializeFdoConnection 1037
#define IDS_STRING_eGwsConnectionParameterNotFound 1038
#define IDS_STRING_eFailedToStartFeatureSourceSession 1039
#define IDS_STRING_eGwsFailedToCacheFeatures 1040
#define IDS_STRING_eGwsLayerSourceNotPartOfGws 1041
#define IDS_STRING_eGwsFeatureSourceDoesnotSupportLongIdentity 1042
#define IDS_STRING_eGwsFailedToDeleteFeature 1043
#define IDS_STRING_eGwsFailedToInsertFeature 1044
#define IDS_STRING_eGwsInvalidParameter 1045
#define IDS_STRING_eGwsIndexOutOfBounds 1046
#define IDS_STRING_eGwsFailedToGetLockInformation 1047
#define IDS_STRING_eGwsObjectsRemainInEditSet 1048
#define IDS_STRING_eGwsOk               1049
#define IDS_STRING_eGwsWarningFailedToLockSomeFeatures 1050
#define IDS_STRING_eGwsWarningFailedToUnlockSomeFeatures 1051
#define IDS_STRING_eGwsWarningFailedToConnectSomeFeatureSources 1052
#define IDS_STRING_eGwsWarningFeatureSourceSessionNotStarted 1053
#define IDS_STRING_eGwsNotSupported     1054
#define IDS_STRING_eGwsFdoProviderError 1055
#define IDS_STRING_eGwsConnected        1056
#define IDS_STRING_eGwsConnectionNotInitialized 1057
#define IDS_STRING_eFailedToStartTransaction 1058
#define IDS_STRING_eGwsNoTransactionStarted 1059
#define IDS_STRING_eGwsFailedToTerminateSession 1060
#define IDS_STRING_eGwsSessionNotFound  1061
#define IDS_STRING_eGwsFailedToFlushChanges 1062
#define IDS_STRING_eGwsFailedToDesribeClass 1063
#define IDS_STRING_eGwsFeatureStorageDoesNotExist 1064
#define IDS_STRING_eGwsFeatureStorageAlreadyCreated 1065
#define IDS_STRING_eGwsFailedToCreateQuery 1066
#define IDS_STRING_eGwsDoesNotSupportRightJoin 1067
#define IDS_STRING_eGwsDoesNotSupportLeftJoin 1068
#define IDS_STRING_eGwsWarningStorageAlreadyLoaded 1069
#define IDS_STRING_eGwsNoExplicitFeatureSourceInLayerQuery 1070
#define IDS_STRING_eGwsDataSourceNotFound 1071
#define IDS_STRING_eGwsDataSourceAlreadyExists 1072
#define IDS_STRING_eGwsDataSourceAlreadyAdded 1073
#define IDS_STRING_eGwsFailedToOpenFdoConnection 1074
#define IDS_STRING_eGwsFailedToCloseFdoConnection 1075
#define IDS_STRING_eGwsFailedToCreateLayerStorage 1076
#define IDS_STRING_eGwsFailedToAddPropertyDefinition 1077
#define IDS_STRING_eGwsFailedToAddIdentityPropertyDefinition 1078
#define IDS_STRING_eGwsFailedToCreateGwsFeatureDefintion 1079
#define IDS_STRING_eGwsStorageNotLoaded 1080
#define IDS_STRING_eGwsFdoReadOnlyProperty 1081
#define IDS_STRING_eGwsFdoQueryIsNotPrepared 1082
#define IDS_STRING_eGwsFdoCommandIsNotPrepared 1083
#define IDS_STRING_eGwsFdoLockConflict  1084
#define IDS_STRING_eGwsFdoVersionConflict 1085
#define IDS_STRING_eGwsFailedToExecuteCommand 1086
#define IDS_STRING_eGwsFailedToPrepareCommand 1087
#define IDS_STRING_eGwsFailedToFetchResults 1088
#define IDS_STRING_eGwsFailedToGetProperty 1089
#define IDS_STRING_eGwsFdoInvalidPropertyType 1090
#define IDS_STRING_eGwsFdoUnsupportedPropertyType 1091
#define IDS_STRING_eFailedToStartLayerSourceSession 1092
#define IDS_STRING_eGwsFeatureDoesNotExist 1093
#define IDS_STRING_eGwsFeatureHasBeenDeleted 1094
#define IDS_STRING_eGwsRevisionNumbersConflict 1095
#define IDS_STRING_eGwsInvalidPropertyName 1096
#define IDS_STRING_eGwsFailedToLockFeatures 1097
#define IDS_STRING_eGwsFailedToUnlockFeatures 1098
#define IDS_STRING_eGwsCannotRemoveNewFeatureFromEditSet 1099
#define IDS_STRING_eGwsJoinPropertiesCardinalityViolation 1100
#define IDS_STRING_eGwsGwsCacheCorrupted 1101
#define IDS_STRING_eGwsFailedToUpdateFeature 1102
#define IDS_STRING_eGwsEditSetUnavailable 1103
#define IDS_STRING_eGwsFailedToSaveGws  1104
#define IDS_STRING_eGwsFailedToDescribeLayer 1105
#define IDS_STRING_eGwsWarningNotCaching 1106
#define IDS_STRING_eGwsWarningStillLoadingCache 1107
#define IDS_STRING_eGwsWarningCacheLoadingStopped 1108
#define IDS_STRING_eGwsItemAlreadyAdded 1109
#define IDS_STRING_eGwsItemNotFound     1110
#define IDS_STRING_eGwsFailedToCommitLayerSourceTransaction 1111
#define IDS_STRING_eGwsCannotGetPropertyValueOffline 1112
#define IDS_STRING_eGwsFeatureNotFoundOnline 1113
#define IDS_STRING_eFailedToCreateMutableFeature 1114
#define IDS_STRING_eGwsFailedToCreateMutableFeature 1114
#define IDS_STRING_eGwsWarinigSomePropertyValuesAreUninitialized 1115
#define IDS_STRING_eGwsWarningSomePropertyValuesAreUninitialized 1115
#define IDS_STRING_eGwsNotAFeatureClass 1116
#define IDS_STRING_eGwsNoGeometryProperty 1117
#define IDS_STRING_eGwsVersionNotFound  1118
#define IDS_STRING_eGwsVersionResolutionFailed 1119
#define IDS_STRING_eGwsFailedToPrepareLayerSourceQuery 1120
#define IDS_STRING_eGwsDeleteCommandNotSupported 1121
#define IDS_STRING_eGwsUpdateCommandNotSupported 1122
#define IDS_STRING_eGwsInsertCommandNotSupported 1123
#define IDS_STRING_eGwsWrongLayerFeatureId 1124
#define IDS_STRING_eGwsFailedToSaveEditSet 1125
#define IDS_STRING_eGwsMissingLeftJoinAttributes 1126
#define IDS_STRING_eGwsInvalidJoinAttributeType 1127
#define IDS_STRING_eGwsJoinAttributesAreNotComparable 1128
#define IDS_STRING_eGwsFailedToDeleteLayerFeature 1129
#define IDS_STRING_eGwsFailedToInsertLayerFeature 1130
#define IDS_STRING_eGwsFailedToUpdateLayerFeature 1131
#define IDS_STRING_eGwsClassNotReferencedByLayer 1132
#define IDS_STRING_eGwsInvalidFeatureSourceName 1133
#define IDS_STRING_eGwsOperationInProgress 1134
#define IDS_STRING_eGwsOperationIsNotRunning 1135
#define IDS_STRING_eGwsOperationCanceled 1136
#define IDS_PROGRESS_READINGMETADATA    1137
#define IDS_PROGRESS_POPULATINGCACHE    1138
#define IDS_PROGRESS_COMMITTING         1139
#define IDS_PROGRESS_COLLECTINGFEATURESTATUS 1140
#define IDS_PROGRESS_UPDATINGFEATURESTATUS 1141
#define IDS_PROGRESS_VERIFYINGREVISIONNUMBERS 1142
#define IDS_PROGRESS_ACQUIRINGLOCKS     1143
#define IDS_PROGRESS_RELEASINGLOCKS     1144
#define IDS_PROGRESS_WRITINGFEATURES    1145
#define IDS_PROGRESS_OPERATIONSTARTED   1146
#define IDS_PROGRESS_COLLECTINGREVISIONNUMBERS 1147
#define IDS_PROGRESS_OPERATIONCANCELED  1148
#define IDS_PROGRESS_OPERATIONFAILED    1149
#define IDS_PROGRESS_OPERATIONWITHWARNING 1150
#define IDS_PROGRESS_OPERATIONSUCESSFUL 1151
#define IDS_STRING_eGwsFailedToTransformFeature 1152
#define IDS_STRING_eGwsFailedToParseFeature 1153
#define IDS_STRING_eGwsSCNotFound       1154
#define IDS_STRING_eGwsFailedToHandleSourceCS 1155
#define IDS_STRING_eGwsFailedToHandleDestinationCS 1156
#define IDS_STRING_eGwsFailedToInitializeCSC 1157
#define IDS_STRING_eGwsFeatureSourceSessionTerminated 1158
#define IDS_STRING_eGwsLayerSourceSessionTerminated 1159
#define IDS_STRING_eGwsWarningFeatureSourceClassIsNotVersionEnabled 1160
#define IDS_STRING_eGwsCannotSetActiveVersion 1161
#define IDS_STRING_eGwsNotAllFeatureSourcesConnected 1162
#define IDS_STRING_eGwsFailedToUpdateLayerSourceVersion 1163
#define IDS_STRING_eGwsCannotMakeUniqueGwsName 1164
#define IDS_PROGRESS_READINGFEATUREIDS  1165
#define IDS_STRING_eGwsWarningExtentsNotYetAvailable 1166
#define IDS_PROGRESS_PROCESSING_LAYER   1167
#define IDS_PROGRESS_PROCESSINGLAYER    1167
#define IDS_STRING1168                  1168
#define IDS_STRING_eGwsProviderNotRegistered 1168
#define IDS_STRING_eGwsSucceeded        1169
#define IDS_STRING_eGwsRevisionNumberConflict 1170
#define IDS_STRING_eGwsLockRejected     1171
#define IDS_STRING_eGwsUnlockRejected   1172
#define IDS_STRING_eGwsLockedOffline    1173
#define IDS_STRING_eGwsCannotUnlockOffline 1174
#define IDS_STRING_eGwsFeatureAlreadyInEditSet 1175
#define IDS_STRING_eGwsSkippedNewFeature 1176
#define IDS_STRING_eGwsSkippedNotLockedFeature 1177
#define IDS_STRING_eGwsFeatureNotSaved  1178
#define IDS_STRING_eGwsNotProcessed     1179
#define IDS_STRING_eGwsCannotRemoveModifedFeatureOffline 1180
#define IDS_STRING_eGwsNewFeatureCannotBeRemoved 1181
#define IDS_STRING_eGwsNewFeatureRemoved 1182
#define IDS_STRING_eGwsRefreshFailedToReloadEditSetFeature 1183
#define IDS_STRING_eGwsRefreshCacheFeatureIsUpTodate 1184
#define IDS_STRING_eGwsRefreshDeletedFeatureInCache 1185
#define IDS_STRING_eGwsRefreshReloadedFeatureInCache 1186
#define IDS_STRING_eGwsRefreshFeatureNotFound 1187
#define IDS_STRING_eGwsFailedToRefreshFeatures 1188
#define IDS_PROGRESS_REFRESHINGLAYERSOURCE 1189
#define IDS_STRING_eGwsNoLayers         1190
#define IDS_STRING_eGwsFeatureSourceIsReadOnly 1191
#define IDS_STRING_eGwsFeatureClassHasNoIdentity 1192
#define IDS_PROGRESS_LAYEREXTENTS       1193
#define IDS_PROGRESS_LAYER              1194
#define IDS_STRING_eGwsFdoInvalidDataType 1195

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        1131
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1000
#define _APS_NEXT_SYMED_VALUE           1000
#endif
#endif
